Angle/Q Tool — LaVue 2.76.0 documentation

# Angle/Q Tool

Angle/Q Tool shows pixel coordinates in q-space or theta-angles

- Geometry: detector geometry parameters. They can be pass in both ways via LavueController tango server

- theta angles or q-space selects the radial transformation

- pixel/polar-th/polar-q: selects Cartesian or polar plot

- Range: select range and scale of polar plots

The radial center can be selected on Cartesian 2D-plot with a mouse double-click.

The configuration of the tool can be set with a JSON dictionary passed in the `--tool-configuration` option in command line or a toolconfig variable of `LavueController.LavueState` with the following keys:

`plot_type` (pixels, polar-th or polar-q string), `units` (angles or q-spaces string), `plot_range` ( (start, end, size) for polar, theta and q coordinates i.e. a list of [float, float, float]), `geometry` (string:float dictionary with the `centerx`, `centery`, `energy`, `pixelsizex`, `pixelsizey`, `detdistance` keywords)

    lavue -u angle/q -s test --tool-configuration \{\"plot_type\":\"polar-q\",\"units\":\"angles\",\"plot_range\":[[0,180,300],[10,30,400],[0,1,500]],\"geometry\":\{\"centerx\":123.4,\"centery\":93.4,\"pixelsizex\":70,\"pixelsizey\":70.2,\"energy\":5050,\"detdistance\":50.5\}\} --start